summaryrefslogtreecommitdiffstats
path: root/kexi/widget/tableview
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/widget/tableview')
-rw-r--r--kexi/widget/tableview/kexiblobtableedit.cpp12
-rw-r--r--kexi/widget/tableview/kexibooltableedit.cpp6
-rw-r--r--kexi/widget/tableview/kexicomboboxbase.cpp2
-rw-r--r--kexi/widget/tableview/kexicomboboxpopup.cpp8
-rw-r--r--kexi/widget/tableview/kexicomboboxtableedit.cpp14
-rw-r--r--kexi/widget/tableview/kexidataawareobjectiface.cpp64
-rw-r--r--kexi/widget/tableview/kexidataawareobjectiface.h22
-rw-r--r--kexi/widget/tableview/kexidataawarepropertyset.cpp6
-rw-r--r--kexi/widget/tableview/kexidataawarepropertyset.h4
-rw-r--r--kexi/widget/tableview/kexidatetableedit.cpp8
-rw-r--r--kexi/widget/tableview/kexidatetimetableedit.cpp6
-rw-r--r--kexi/widget/tableview/kexiinputtableedit.cpp10
-rw-r--r--kexi/widget/tableview/kexitableedit.cpp4
-rw-r--r--kexi/widget/tableview/kexitableitem.cpp2
-rw-r--r--kexi/widget/tableview/kexitableview.cpp144
-rw-r--r--kexi/widget/tableview/kexitableview.h30
-rw-r--r--kexi/widget/tableview/kexitableview_p.cpp2
-rw-r--r--kexi/widget/tableview/kexitableviewdata.cpp52
-rw-r--r--kexi/widget/tableview/kexitableviewdata.h26
-rw-r--r--kexi/widget/tableview/kexitableviewheader.cpp10
-rw-r--r--kexi/widget/tableview/kexitimetableedit.cpp6
21 files changed, 219 insertions, 219 deletions
diff --git a/kexi/widget/tableview/kexiblobtableedit.cpp b/kexi/widget/tableview/kexiblobtableedit.cpp
index 2700477a..7ad76c34 100644
--- a/kexi/widget/tableview/kexiblobtableedit.cpp
+++ b/kexi/widget/tableview/kexiblobtableedit.cpp
@@ -25,8 +25,8 @@
#include <tqdatastream.h>
#include <tqfile.h>
#include <tqpopupmenu.h>
-#include <textedit.h>
-#include <layout.h>
+#include <tqtextedit.h>
+#include <tqlayout.h>
#include <tqstatusbar.h>
#include <tqlabel.h>
#include <tqpixmap.h>
@@ -34,7 +34,7 @@
#include <tqpainter.h>
#include <tqtooltip.h>
#include <tqapplication.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqbuffer.h>
#include <kdebug.h>
@@ -309,14 +309,14 @@ void KexiBlobTableEdit::executeCopyAction(const TQByteArray& data)
TQPixmap pixmap;
if (!pixmap.loadFromData(data))
return;
- tqApp->clipboard()->setPixmap(pixmap, TQClipboard::Clipboard);
+ tqApp->tqclipboard()->setPixmap(pixmap, TQClipboard::Clipboard);
}
void KexiBlobTableEdit::handlePasteAction()
{
if (isReadOnly())
return;
- TQPixmap pm( tqApp->clipboard()->pixmap(TQClipboard::Clipboard) );
+ TQPixmap pm( tqApp->tqclipboard()->pixmap(TQClipboard::Clipboard) );
TQByteArray ba;
TQBuffer buffer( ba );
buffer.open( IO_WriteOnly );
@@ -559,7 +559,7 @@ void KexiKIconTableEdit::setupContents( TQPainter *p, bool /*focused*/, const TQ
s = TQMIN( h-3, s );
s = TQMIN( w-3, s );//avoid too large box
TQRect r( TQMAX( w/2 - s/2, 0 ) , h/2 - s/2 /*- 1*/, s, s);
- p->setPen(TQPen(colorGroup().text(), 1));
+ p->setPen(TQPen(tqcolorGroup().text(), 1));
p->drawRect(r);
if (val.asBool()) {
p->drawLine(r.x(), r.y(), r.right(), r.bottom());
diff --git a/kexi/widget/tableview/kexibooltableedit.cpp b/kexi/widget/tableview/kexibooltableedit.cpp
index 950d19b7..8f199b5d 100644
--- a/kexi/widget/tableview/kexibooltableedit.cpp
+++ b/kexi/widget/tableview/kexibooltableedit.cpp
@@ -23,7 +23,7 @@
#include <tqpainter.h>
#include <tqapplication.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <kglobal.h>
#include <klocale.h>
@@ -105,7 +105,7 @@ void KexiBoolTableEdit::setupContents( TQPainter *p, bool focused, const TQVaria
s = TQMIN( h-3, s );
s = TQMIN( w-3, s );//avoid too large box
TQRect r( TQMAX( w/2 - s/2, 0 ) , h/2 - s/2 /*- 1*/, s, s);
-//already set ouotside: p->setPen(TQPen(colorGroup().text(), 1));
+//already set ouotside: p->setPen(TQPen(tqcolorGroup().text(), 1));
p->drawRect(r);
if (val.isNull()) { // && !field()->isNotNull()) {
p->drawText( r, TQt::AlignCenter, "?" );
@@ -135,7 +135,7 @@ void KexiBoolTableEdit::handleAction(const TQString& actionName)
if (actionName=="edit_paste") {
emit editRequested();
bool ok;
- const int value = tqApp->clipboard()->text( TQClipboard::Clipboard ).toInt(&ok);
+ const int value = tqApp->tqclipboard()->text( TQClipboard::Clipboard ).toInt(&ok);
if (ok) {
m_currentValue = (value==0) ? TQVariant(false, 0) : TQVariant(true, 1);
}
diff --git a/kexi/widget/tableview/kexicomboboxbase.cpp b/kexi/widget/tableview/kexicomboboxbase.cpp
index be2f81be..89ba63cf 100644
--- a/kexi/widget/tableview/kexicomboboxbase.cpp
+++ b/kexi/widget/tableview/kexicomboboxbase.cpp
@@ -18,7 +18,7 @@
* Boston, MA 02110-1301, USA.
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqstyle.h>
#include <tqwindowsstyle.h>
#include <tqpainter.h>
diff --git a/kexi/widget/tableview/kexicomboboxpopup.cpp b/kexi/widget/tableview/kexicomboboxpopup.cpp
index 5e74a20e..6a2feec8 100644
--- a/kexi/widget/tableview/kexicomboboxpopup.cpp
+++ b/kexi/widget/tableview/kexicomboboxpopup.cpp
@@ -30,7 +30,7 @@
#include <kdebug.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqevent.h>
/*! @internal
@@ -56,8 +56,8 @@ class KexiComboBoxPopup_KexiTableView : public KexiDataTableView
a.rowHighlightingEnabled = true;
a.rowMouseOverHighlightingEnabled = true;
a.persistentSelections = false;
- a.rowMouseOverHighlightingColor = colorGroup().highlight();
- a.rowMouseOverHighlightingTextColor = colorGroup().highlightedText();
+ a.rowMouseOverHighlightingColor = tqcolorGroup().highlight();
+ a.rowMouseOverHighlightingTextColor = tqcolorGroup().highlightedText();
a.rowHighlightingTextColor = a.rowMouseOverHighlightingTextColor;
a.gridEnabled = false;
setAppearance(a);
@@ -68,7 +68,7 @@ class KexiComboBoxPopup_KexiTableView : public KexiDataTableView
setContextMenuEnabled( false );
setScrollbarToolTipsEnabled( false );
installEventFilter(this);
- setBottomMarginInternal( - horizontalScrollBar()->sizeHint().height() );
+ setBottomMarginInternal( - horizontalScrollBar()->tqsizeHint().height() );
}
virtual void setData( KexiTableViewData *data, bool owner = true )
{ KexiTableView::setData( data, owner ); }
diff --git a/kexi/widget/tableview/kexicomboboxtableedit.cpp b/kexi/widget/tableview/kexicomboboxtableedit.cpp
index 24c4c38f..3ae97974 100644
--- a/kexi/widget/tableview/kexicomboboxtableedit.cpp
+++ b/kexi/widget/tableview/kexicomboboxtableedit.cpp
@@ -18,12 +18,12 @@
* Boston, MA 02110-1301, USA.
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqstyle.h>
#include <tqwindowsstyle.h>
#include <tqpainter.h>
#include <tqapplication.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include "kexicomboboxtableedit.h"
#include <widget/utils/kexicomboboxdropdownbutton.h>
@@ -80,11 +80,11 @@ KexiComboBoxTableEdit::KexiComboBoxTableEdit(KexiTableViewColumn &column, TQWidg
// m_lineedit->setFrameStyle( TQFrame::Plain | TQFrame::Box );
// m_lineedit->setLineWidth( 1 );
// if (f.isNumericType()) {
-// m_lineedit->setAlignment(AlignRight);
+// m_lineedit->tqsetAlignment(AlignRight);
// }
// setView( m_lineedit );
-// layout->addWidget(m_view);
+// tqlayout->addWidget(m_view);
// m_combo->setEditable( true );
// m_combo->clear();
// m_combo->insertStringList(f.enumHints());
@@ -350,8 +350,8 @@ bool KexiComboBoxTableEdit::eventFilter( TQObject *o, TQEvent *e )
if (!column()->isReadOnly() && e->type()==TQEvent::MouseButtonPress && m_scrollView) {
TQPoint gp = TQT_TQMOUSEEVENT(e)->globalPos()
+ TQPoint(m_scrollView->childX(d->button), m_scrollView->childY(d->button));
- TQRect r(d->button->mapToGlobal(d->button->geometry().topLeft()),
- d->button->mapToGlobal(d->button->geometry().bottomRight()));
+ TQRect r(d->button->mapToGlobal(d->button->tqgeometry().topLeft()),
+ d->button->mapToGlobal(d->button->tqgeometry().bottomRight()));
if (TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(popup()) && popup()->isVisible() && r.contains( gp )) {
m_mouseBtnPressedWhenPopupVisible = true;
}
@@ -434,7 +434,7 @@ void KexiComboBoxTableEdit::handleAction(const TQString& actionName)
m_lineedit->clear();
}
//! @todo does not work with BLOBs!
- setValueInInternalEditor( tqApp->clipboard()->text() );
+ setValueInInternalEditor( tqApp->tqclipboard()->text() );
}
else
KexiInputTableEdit::handleAction(actionName);
diff --git a/kexi/widget/tableview/kexidataawarepropertyset.cpp b/kexi/widget/tableview/kexidataawarepropertyset.cpp
index 3b9fe3af..257cf0aa 100644
--- a/kexi/widget/tableview/kexidataawarepropertyset.cpp
+++ b/kexi/widget/tableview/kexidataawarepropertyset.cpp
@@ -92,10 +92,10 @@ uint KexiDataAwarePropertySet::size() const
return m_sets.size();
}
-void KexiDataAwarePropertySet::clear(uint minimumSize)
+void KexiDataAwarePropertySet::clear(uint tqminimumSize)
{
m_sets.clear();
- m_sets.resize(TQMAX(minimumSize, MAX_FIELDS));
+ m_sets.resize(TQMAX(tqminimumSize, MAX_FIELDS));
m_view->setDirty(true);
m_view->propertySetSwitched();
}
@@ -206,7 +206,7 @@ void KexiDataAwarePropertySet::slotRowsDeleted( const TQValueList<int> &rows )
}
//void KexiDataAwarePropertySet::slotEmptyRowInserted(KexiTableItem*, uint /*index*/)
-void KexiDataAwarePropertySet::slotRowInserted(KexiTableItem*, uint row, bool /*repaint*/)
+void KexiDataAwarePropertySet::slotRowInserted(KexiTableItem*, uint row, bool /*tqrepaint*/)
{
m_view->setDirty();
diff --git a/kexi/widget/tableview/kexidataawarepropertyset.h b/kexi/widget/tableview/kexidataawarepropertyset.h
index 8db82ba2..e24fbd8a 100644
--- a/kexi/widget/tableview/kexidataawarepropertyset.h
+++ b/kexi/widget/tableview/kexidataawarepropertyset.h
@@ -97,7 +97,7 @@ class KEXIDATATABLE_EXPORT KexiDataAwarePropertySet : public TQObject
public slots:
void removeCurrentPropertySet();
- void clear(uint minimumSize = 0);
+ void clear(uint tqminimumSize = 0);
/*! Inserts \a set property set at \a row position.
If there was a buffer at this position before, it will be destroyed.
@@ -127,7 +127,7 @@ class KEXIDATATABLE_EXPORT KexiDataAwarePropertySet : public TQObject
void slotRowsDeleted( const TQValueList<int> &rows );
//! Called on \a row insertion in a tableview.
- void slotRowInserted(KexiTableItem* item, uint row, bool repaint);
+ void slotRowInserted(KexiTableItem* item, uint row, bool tqrepaint);
//! Called on selecting another cell in a tableview.
void slotCellSelected(int, int row);
diff --git a/kexi/widget/tableview/kexidatetableedit.cpp b/kexi/widget/tableview/kexidatetableedit.cpp
index 5a8cf297..b68b4787 100644
--- a/kexi/widget/tableview/kexidatetableedit.cpp
+++ b/kexi/widget/tableview/kexidatetableedit.cpp
@@ -25,16 +25,16 @@
#include <tqpainter.h>
#include <tqvariant.h>
#include <tqrect.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqcolor.h>
#include <tqfontmetrics.h>
#include <tqdatetime.h>
#include <tqcursor.h>
#include <tqpoint.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtoolbutton.h>
#include <tqdatetimeedit.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <kdebug.h>
#include <klocale.h>
@@ -163,7 +163,7 @@ void
KexiDateTableEdit::slotDateChanged(TQDate date)
{
m_edit->setDate(date);
- repaint();
+ tqrepaint();
}
void
diff --git a/kexi/widget/tableview/kexidatetimetableedit.cpp b/kexi/widget/tableview/kexidatetimetableedit.cpp
index 7d33b354..35c599cc 100644
--- a/kexi/widget/tableview/kexidatetimetableedit.cpp
+++ b/kexi/widget/tableview/kexidatetimetableedit.cpp
@@ -25,16 +25,16 @@
#include <tqpainter.h>
#include <tqvariant.h>
#include <tqrect.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqcolor.h>
#include <tqfontmetrics.h>
#include <tqdatetime.h>
#include <tqcursor.h>
#include <tqpoint.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtoolbutton.h>
#include <tqdatetimeedit.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <kdebug.h>
#include <klocale.h>
diff --git a/kexi/widget/tableview/kexiinputtableedit.cpp b/kexi/widget/tableview/kexiinputtableedit.cpp
index d057f517..1b834fe9 100644
--- a/kexi/widget/tableview/kexiinputtableedit.cpp
+++ b/kexi/widget/tableview/kexiinputtableedit.cpp
@@ -22,11 +22,11 @@
#include <tqregexp.h>
#include <tqevent.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtimer.h>
#include <tqpainter.h>
#include <tqapplication.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqtooltip.h>
#include <kglobal.h>
@@ -47,7 +47,7 @@ class MyLineEdit : public KLineEdit
{}
protected:
virtual void drawFrame ( TQPainter * p ) {
- p->setPen( TQPen( colorGroup().text() ) );
+ p->setPen( TQPen( tqcolorGroup().text() ) );
TQRect r = rect();
p->moveTo( r.topLeft() );
p->lineTo( r.topRight() );
@@ -100,7 +100,7 @@ void KexiInputTableEdit::init()
m_lineedit = new MyLineEdit(this, "KexiInputTableEdit-KLineEdit");
setViewWidget(m_lineedit);
if (align_right)
- m_lineedit->setAlignment(AlignRight);
+ m_lineedit->tqsetAlignment(AlignRight);
// m_cview->setFrame(false);
// m_cview->setFrameStyle( TQFrame::Plain | TQFrame::Box );
// m_cview->setLineWidth( 1 );
@@ -222,7 +222,7 @@ TQString KexiInputTableEdit::valueToText(KexiDB::Field* field, const TQVariant&
void KexiInputTableEdit::paintEvent ( TQPaintEvent * /*e*/ )
{
TQPainter p(this);
- p.setPen( TQPen( colorGroup().text() ) );
+ p.setPen( TQPen( tqcolorGroup().text() ) );
p.drawRect( rect() );
}
diff --git a/kexi/widget/tableview/kexitableedit.cpp b/kexi/widget/tableview/kexitableedit.cpp
index 68991f49..e531b814 100644
--- a/kexi/widget/tableview/kexitableedit.cpp
+++ b/kexi/widget/tableview/kexitableedit.cpp
@@ -23,7 +23,7 @@
#include <kexidb/field.h>
#include <kexidb/utils.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqpainter.h>
#include <kglobal.h>
@@ -101,7 +101,7 @@ void KexiTableEdit::resize(int w, int h)
{
TQWidget::resize(w, h);
if (m_view) {
- if (!layout()) { //if there is layout (eg. KexiInputTableEdit), resize is automatic
+ if (!tqlayout()) { //if there is tqlayout (eg. KexiInputTableEdit), resize is automatic
m_view->move(0,0);
m_view->resize(w, h);
}
diff --git a/kexi/widget/tableview/kexitableitem.cpp b/kexi/widget/tableview/kexitableitem.cpp
index d398dabb..659e341e 100644
--- a/kexi/widget/tableview/kexitableitem.cpp
+++ b/kexi/widget/tableview/kexitableitem.cpp
@@ -55,7 +55,7 @@ KexiTableItem::clearValues()
void
KexiTableItem::debug() const
{
- TQString s = TQString("KexiTableItem (%1 items)").arg(size());
+ TQString s = TQString("KexiTableItem (%1 items)").tqarg(size());
for (uint i = 0; i < size(); i++)
s.append( TQString::number(i)+":"+at(i).toString()+" " );
kexidbg << s << endl;
diff --git a/kexi/widget/tableview/kexitableview.cpp b/kexi/widget/tableview/kexitableview.cpp
index eeb4e378..4ed993cd 100644
--- a/kexi/widget/tableview/kexitableview.cpp
+++ b/kexi/widget/tableview/kexitableview.cpp
@@ -33,7 +33,7 @@
#include <tqpopupmenu.h>
#include <tqcursor.h>
#include <tqstyle.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqwhatsthis.h>
@@ -102,10 +102,10 @@ class KexiTableView::WhatsThis : public TQWhatsThis
const int leftMargin = m_tv->verticalHeaderVisible() ? m_tv->verticalHeader()->width() : 0;
//const int topMargin = m_tv->horizontalHeaderVisible() ? m_tv->d->pTopHeader->height() : 0;
//const int bottomMargin = m_tv->d->appearance.navigatorEnabled ? m_tv->m_navPanel->height() : 0;
- if (KexiUtils::hasParent(TQT_TQOBJECT(m_tv->verticalHeader()), TQT_TQOBJECT(m_tv->childAt(pos)))) {
+ if (KexiUtils::hasParent(TQT_TQOBJECT(m_tv->verticalHeader()), TQT_TQOBJECT(m_tv->tqchildAt(pos)))) {
return i18n("Contains a pointer to the currently selected row");
}
- else if (KexiUtils::hasParent(TQT_TQOBJECT(m_tv->m_navPanel), TQT_TQOBJECT(m_tv->childAt(pos)))) {
+ else if (KexiUtils::hasParent(TQT_TQOBJECT(m_tv->m_navPanel), TQT_TQOBJECT(m_tv->tqchildAt(pos)))) {
return i18n("Row navigator");
// return TQWhatsThis::textFor(m_tv->m_navPanel, TQPoint( pos.x(), pos.y() - m_tv->height() + bottomMargin ));
}
@@ -204,8 +204,8 @@ KexiTableView::KexiTableView(KexiTableViewData* data, TQWidget* parent, const ch
setBackgroundMode(TQt::PaletteBackground);
// setEmptyAreaColor(d->appearance.baseColor);//palette().active().color(TQColorGroup::Base));
-// d->baseColor = colorGroup().base();
-// d->textColor = colorGroup().text();
+// d->baseColor = tqcolorGroup().base();
+// d->textColor = tqcolorGroup().text();
// d->altColor = KGlobalSettings::alternateBackgroundColor();
// d->grayColor = TQColor(200,200,200);
@@ -240,21 +240,21 @@ KexiTableView::KexiTableView(KexiTableViewData* data, TQWidget* parent, const ch
// Create headers
m_horizontalHeader = new KexiTableViewHeader(this, "topHeader");
- m_horizontalHeader->setSelectionBackgroundColor( palette().active().highlight() );
+ m_horizontalHeader->setSelectionBackgroundColor( tqpalette().active().highlight() );
m_horizontalHeader->setOrientation(Qt::Horizontal);
m_horizontalHeader->setTracking(false);
m_horizontalHeader->setMovingEnabled(false);
connect(m_horizontalHeader, TQT_SIGNAL(sizeChange(int,int,int)), this, TQT_SLOT(slotTopHeaderSizeChange(int,int,int)));
m_verticalHeader = new KexiRecordMarker(this, "rm");
- m_verticalHeader->setSelectionBackgroundColor( palette().active().highlight() );
+ m_verticalHeader->setSelectionBackgroundColor( tqpalette().active().highlight() );
m_verticalHeader->setCellHeight(d->rowHeight);
// m_verticalHeader->setFixedWidth(d->rowHeight);
m_verticalHeader->setCurrentRow(-1);
setMargins(
- TQMIN(m_horizontalHeader->sizeHint().height(), d->rowHeight),
- m_horizontalHeader->sizeHint().height(), 0, 0);
+ TQMIN(m_horizontalHeader->tqsizeHint().height(), d->rowHeight),
+ m_horizontalHeader->tqsizeHint().height(), 0, 0);
setupNavigator();
@@ -288,7 +288,7 @@ KexiTableView::KexiTableView(KexiTableViewData* data, TQWidget* parent, const ch
// horizontalScrollBar()->show();
updateScrollBars();
-// resize(sizeHint());
+// resize(tqsizeHint());
// updateContents();
// setMinimumHeight(horizontalScrollBar()->height() + d->rowHeight + topMargin());
@@ -333,7 +333,7 @@ void KexiTableView::setupNavigator()
m_navPanel = new KexiRecordNavigator(this, leftMargin(), "navPanel");
m_navPanel->setRecordHandler(this);
- m_navPanel->setSizePolicy(TQSizePolicy::Minimum,TQSizePolicy::Preferred);
+ m_navPanel->tqsetSizePolicy(TQSizePolicy::Minimum,TQSizePolicy::Preferred);
}
void KexiTableView::initDataContents()
@@ -366,7 +366,7 @@ void KexiTableView::updateWidgetContentsSize()
void KexiTableView::slotRowsDeleted( const TQValueList<int> &rows )
{
- viewport()->repaint();
+ viewport()->tqrepaint();
updateWidgetContentsSize();
setCursorPosition(TQMAX(0, (int)m_curRow - (int)rows.count()), -1, true);
}
@@ -384,7 +384,7 @@ void KexiTableView::setFont( const TQFont &font )
updateFonts(true);
}
-void KexiTableView::updateFonts(bool repaint)
+void KexiTableView::updateFonts(bool tqrepaint)
{
#ifdef TQ_WS_WIN
d->rowHeight = fontMetrics().lineSpacing() + 4;
@@ -399,15 +399,15 @@ void KexiTableView::updateFonts(bool repaint)
// if(d->rowHeight < 22)
// d->rowHeight = 22;
setMargins(
- TQMIN(m_horizontalHeader->sizeHint().height(), d->rowHeight),
- m_horizontalHeader->sizeHint().height(), 0, 0);
+ TQMIN(m_horizontalHeader->tqsizeHint().height(), d->rowHeight),
+ m_horizontalHeader->tqsizeHint().height(), 0, 0);
// setMargins(14, d->rowHeight, 0, 0);
m_verticalHeader->setCellHeight(d->rowHeight);
KexiDisplayUtils::initDisplayForAutonumberSign(d->autonumberSignDisplayParameters, this);
KexiDisplayUtils::initDisplayForDefaultValue(d->defaultValueDisplayParameters, this);
- if (repaint)
+ if (tqrepaint)
updateContents();
}
@@ -425,7 +425,7 @@ void KexiTableView::updateAllVisibleRowsBelow(int row)
clipper()->width(), clipper()->height() - (rowPos(row) - contentsY()) );
}
-void KexiTableView::clearColumnsInternal(bool /*repaint*/)
+void KexiTableView::clearColumnsInternal(bool /*tqrepaint*/)
{
while(m_horizontalHeader->count()>0)
m_horizontalHeader->removeLabel(0);
@@ -494,29 +494,29 @@ TQSizePolicy KexiTableView::sizePolicy() const
return TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding);
}
-TQSize KexiTableView::sizeHint() const
+TQSize KexiTableView::tqsizeHint() const
{
const TQSize &ts = tableSize();
- int w = TQMAX( ts.width() + leftMargin()+ verticalScrollBar()->sizeHint().width() + 2*2,
+ int w = TQMAX( ts.width() + leftMargin()+ verticalScrollBar()->tqsizeHint().width() + 2*2,
(m_navPanel->isVisible() ? m_navPanel->width() : 0) );
- int h = TQMAX( ts.height()+topMargin()+horizontalScrollBar()->sizeHint().height(),
- minimumSizeHint().height() );
+ int h = TQMAX( ts.height()+topMargin()+horizontalScrollBar()->tqsizeHint().height(),
+ tqminimumSizeHint().height() );
w = TQMIN( w, tqApp->desktop()->width()*3/4 ); //stretch
h = TQMIN( h, tqApp->desktop()->height()*3/4 ); //stretch
-// kexidbg << "KexiTableView::sizeHint()= " <<w <<", " <<h << endl;
+// kexidbg << "KexiTableView::tqsizeHint()= " <<w <<", " <<h << endl;
return TQSize(w, h);
/*TQSize(
TQMAX( ts.width() + leftMargin() + 2*2, (m_navPanel ? m_navPanel->width() : 0) ),
//+ TQMIN(m_verticalHeader->width(),d->rowHeight) + margin()*2,
- TQMAX( ts.height()+topMargin()+horizontalScrollBar()->sizeHint().height(),
- minimumSizeHint().height() )
+ TQMAX( ts.height()+topMargin()+horizontalScrollBar()->tqsizeHint().height(),
+ tqminimumSizeHint().height() )
);*/
-// TQMAX(ts.height() + topMargin(), minimumSizeHint().height()) );
+// TQMAX(ts.height() + topMargin(), tqminimumSizeHint().height()) );
}
-TQSize KexiTableView::minimumSizeHint() const
+TQSize KexiTableView::tqminimumSizeHint() const
{
return TQSize(
leftMargin() + ((columns()>0)?columnWidth(0):KEXI_DEFAULT_DATA_COLUMN_WIDTH) + 2*2,
@@ -614,7 +614,7 @@ void KexiTableView::drawContents( TQPainter *p, int cx, int cy, int cw, int ch)
bool paintOnlyInsertRow = false;
/* kdDebug(44021) << TQString(" KexiTableView::drawContents(cx:%1 cy:%2 cw:%3 ch:%4)")
- .arg(cx).arg(cy).arg(cw).arg(ch) << endl;*/
+ .tqarg(cx).tqarg(cy).tqarg(cw).tqarg(ch) << endl;*/
if (rowlast == -1) {
rowlast = rows() - 1;
@@ -658,7 +658,7 @@ void KexiTableView::drawContents( TQPainter *p, int cx, int cy, int cw, int ch)
if(d->pBufferPm->isNull())
return;
TQPainter *pb = new TQPainter(d->pBufferPm, this);
-// pb->fillRect(0, 0, cw, ch, colorGroup().base());
+// pb->fillRect(0, 0, cw, ch, tqcolorGroup().base());
// int maxwc = TQMIN(cw, (columnPos(d->numCols - 1) + columnWidth(d->numCols - 1)));
int maxwc = columnPos(columns() - 1) + columnWidth(columns() - 1);
@@ -812,7 +812,7 @@ void KexiTableView::paintCell(TQPainter* p, KexiTableItem *item, int col, int ro
&& !dontPaintNonpersistentSelectionBecauseDifferentRowHasBeenHighlighted
&& usesSelectedTextColor)
{
- defaultPen = TQPen(colorGroup().highlightedText()); //selected text
+ defaultPen = TQPen(tqcolorGroup().highlightedText()); //selected text
}
else if (d->appearance.rowHighlightingEnabled && row == m_curRow
&& !dontPaintNonpersistentSelectionBecauseDifferentRowHasBeenHighlighted
@@ -849,7 +849,7 @@ void KexiTableView::paintCell(TQPainter* p, KexiTableItem *item, int col, int ro
if (m_currentItem == item && (col == m_curCol || d->appearance.fullRowSelection)) {
if (edit && ((d->appearance.rowHighlightingEnabled && !d->appearance.fullRowSelection) || (row == m_curRow && d->highlightedRow==-1 && d->appearance.fullRowSelection))) //!dontPaintNonpersistentSelectionBecauseDifferentRowHasBeenHighlighted)
edit->paintSelectionBackground( p, isEnabled(), txt, align, x, y_offset, w, h,
- isEnabled() ? colorGroup().highlight() : TQColor(200,200,200),//d->grayColor,
+ isEnabled() ? tqcolorGroup().highlight() : TQColor(200,200,200),//d->grayColor,
p->fontMetrics(), columnReadOnly, d->appearance.fullRowSelection );
}
@@ -931,9 +931,9 @@ void KexiTableView::paintEmptyArea( TQPainter *p, int cx, int cy, int cw, int ch
// ts.setWidth( TQMIN( ts.width(), visibleWidth() ) );
// ts.setHeight( TQMIN( ts.height() - (m_navPanel ? m_navPanel->height() : 0), visibleHeight()) );
/* kdDebug(44021) << TQString(" (cx:%1 cy:%2 cw:%3 ch:%4)")
- .arg(cx).arg(cy).arg(cw).arg(ch) << endl;
+ .tqarg(cx).tqarg(cy).tqarg(cw).tqarg(ch) << endl;
kdDebug(44021) << TQString(" (w:%3 h:%4)")
- .arg(ts.width()).arg(ts.height()) << endl;*/
+ .tqarg(ts.width()).tqarg(ts.height()) << endl;*/
// Region of the rect we should draw, calculated in viewport
// coordinates, as a region can't handle bigger coordinates
@@ -945,26 +945,26 @@ void KexiTableView::paintEmptyArea( TQPainter *p, int cx, int cy, int cw, int ch
// Subtract the table from it
// reg = reg.subtract( TQRect( TQPoint( 0, 0 ), ts-TQSize(0,m_navPanel->isVisible() ? m_navPanel->height() : 0) ) );
reg = reg.subtract( TQRect( TQPoint( 0, 0 ), ts
- -TQSize(0,TQMAX((m_navPanel ? m_navPanel->height() : 0), horizontalScrollBar()->sizeHint().height())
- - (horizontalScrollBar()->isVisible() ? horizontalScrollBar()->sizeHint().height()/2 : 0)
+ -TQSize(0,TQMAX((m_navPanel ? m_navPanel->height() : 0), horizontalScrollBar()->tqsizeHint().height())
+ - (horizontalScrollBar()->isVisible() ? horizontalScrollBar()->tqsizeHint().height()/2 : 0)
+ (horizontalScrollBar()->isVisible() ? 0 :
d->internal_bottomMargin
-// horizontalScrollBar()->sizeHint().height()/2
+// horizontalScrollBar()->tqsizeHint().height()/2
)
-//- /*d->bottomMargin */ horizontalScrollBar()->sizeHint().height()*3/2
+//- /*d->bottomMargin */ horizontalScrollBar()->tqsizeHint().height()*3/2
+ contentsY()
-// - (verticalScrollBar()->isVisible() ? horizontalScrollBar()->sizeHint().height()/2 : 0)
+// - (verticalScrollBar()->isVisible() ? horizontalScrollBar()->tqsizeHint().height()/2 : 0)
)
) );
// reg = reg.subtract( TQRect( TQPoint( 0, 0 ), ts ) );
// And draw the rectangles (transformed inc contents coordinates as needed)
- TQMemArray<TQRect> r = reg.rects();
+ TQMemArray<TQRect> r = reg.tqrects();
for ( int i = 0; i < (int)r.count(); i++ ) {
TQRect rect( viewportToContents2(r[i].topLeft()), r[i].size() );
/* kdDebug(44021) << TQString("- pEA: p->fillRect(x:%1 y:%2 w:%3 h:%4)")
- .arg(rect.x()).arg(rect.y())
- .arg(rect.width()).arg(rect.height()) << endl;*/
+ .tqarg(rect.x()).tqarg(rect.y())
+ .tqarg(rect.width()).tqarg(rect.height()) << endl;*/
// p->fillRect( TQRect(viewportToContents2(r[i].topLeft()),r[i].size()), d->emptyAreaColor );
p->fillRect( rect, d->appearance.emptyAreaColor );
// p->fillRect( TQRect(viewportToContents2(r[i].topLeft()),r[i].size()), viewport()->backgroundBrush() );
@@ -1261,7 +1261,7 @@ void KexiTableView::keyPressEvent(TQKeyEvent* e)
const int k = e->key();
const bool ro = isReadOnly();
- TQWidget *w = focusWidget();
+ TQWidget *w = tqfocusWidget();
// if (!w || w!=viewport() && w!=this && (!m_editor || w!=m_editor->view() && w!=m_editor)) {
// if (!w || w!=viewport() && w!=this && (!m_editor || w!=m_editor->view())) {
if (!w || TQT_BASE_OBJECT(w)!=TQT_BASE_OBJECT(viewport()) && TQT_TQOBJECT(w)!=TQT_TQOBJECT(this) && (!m_editor || !KexiUtils::hasParent(TQT_TQOBJECT(dynamic_cast<TQT_BASE_OBJECT_NAME*>(m_editor)), TQT_TQOBJECT(w)))) {
@@ -1425,7 +1425,7 @@ void KexiTableView::keyPressEvent(TQKeyEvent* e)
else {
kexidbg << "KexiTableView::KeyPressEvent(): default" << endl;
if (e->text().isEmpty() || !e->text().isEmpty() && !e->text()[0].isPrint() ) {
- kdDebug(44021) << "NOT PRINTABLE: 0x0" << TQString("%1").arg(k,0,16) <<endl;
+ kdDebug(44021) << "NOT PRINTABLE: 0x0" << TQString("%1").tqarg(k,0,16) <<endl;
// e->ignore();
TQScrollView::keyPressEvent(e);
return;
@@ -1450,7 +1450,7 @@ void KexiTableView::keyPressEvent(TQKeyEvent* e)
m_vScrollBarValueChanged_enabled=false;
- // if focus cell changes, repaint
+ // if focus cell changes, tqrepaint
setCursorPosition(curRow, curCol);
m_vScrollBarValueChanged_enabled=true;
@@ -1630,29 +1630,29 @@ void KexiTableView::resizeEvent(TQResizeEvent *e)
slotUpdate();
triggerUpdate();
}
-// d->pTopHeader->repaint();
+// d->pTopHeader->tqrepaint();
/* m_navPanel->setGeometry(
frameWidth(),
viewport()->height() +d->pTopHeader->height()
- -(horizontalScrollBar()->isVisible() ? 0 : horizontalScrollBar()->sizeHint().height())
+ -(horizontalScrollBar()->isVisible() ? 0 : horizontalScrollBar()->tqsizeHint().height())
+frameWidth(),
- m_navPanel->sizeHint().width(), // - verticalScrollBar()->sizeHint().width() - horizontalScrollBar()->sizeHint().width(),
- horizontalScrollBar()->sizeHint().height()
+ m_navPanel->tqsizeHint().width(), // - verticalScrollBar()->tqsizeHint().width() - horizontalScrollBar()->tqsizeHint().width(),
+ horizontalScrollBar()->tqsizeHint().height()
);*/
// updateContents();
// m_navPanel->setGeometry(1,horizontalScrollBar()->pos().y(),
// m_navPanel->width(), horizontalScrollBar()->height());
// updateContents(0,0,2000,2000);//js
-// erase(); repaint();
+// erase(); tqrepaint();
}
void KexiTableView::viewportResizeEvent( TQResizeEvent *e )
{
TQScrollView::viewportResizeEvent( e );
updateGeometries();
-// erase(); repaint();
+// erase(); tqrepaint();
}
void KexiTableView::showEvent(TQShowEvent *e)
@@ -1818,7 +1818,7 @@ void KexiTableView::slotColumnWidthChanged( int, int, int )
else {
// updateContents( columnPos(col), 0, contentsWidth(), contentsHeight() );
updateContents(contentsX(), 0, viewport()->width(), contentsHeight());
- // viewport()->repaint();
+ // viewport()->tqrepaint();
}
// updateContents(0, 0, d->pBufferPm->width(), d->pBufferPm->height());
@@ -1923,42 +1923,42 @@ TQSize KexiTableView::tableSize() const
if ((rows()+ (isInsertingEnabled()?1:0) ) > 0 && columns() > 0) {
/* kexidbg << "tableSize()= " << columnPos( columns() - 1 ) + columnWidth( columns() - 1 )
<< ", " << rowPos( rows()-1+(isInsertingEnabled()?1:0)) + d->rowHeight
-// + TQMAX(m_navPanel ? m_navPanel->height() : 0, horizontalScrollBar()->sizeHint().height())
- + (m_navPanel->isVisible() ? TQMAX( m_navPanel->height(), horizontalScrollBar()->sizeHint().height() ) :0 )
+// + TQMAX(m_navPanel ? m_navPanel->height() : 0, horizontalScrollBar()->tqsizeHint().height())
+ + (m_navPanel->isVisible() ? TQMAX( m_navPanel->height(), horizontalScrollBar()->tqsizeHint().height() ) :0 )
+ margin() << endl;
*/
// kexidbg<< m_navPanel->isVisible() <<" "<<m_navPanel->height()<<" "
-// <<horizontalScrollBar()->sizeHint().height()<<" "<<rowPos( rows()-1+(isInsertingEnabled()?1:0))<<endl;
+// <<horizontalScrollBar()->tqsizeHint().height()<<" "<<rowPos( rows()-1+(isInsertingEnabled()?1:0))<<endl;
- //int xx = horizontalScrollBar()->sizeHint().height()/2;
+ //int xx = horizontalScrollBar()->tqsizeHint().height()/2;
TQSize s(
columnPos( columns() - 1 ) + columnWidth( columns() - 1 ),
-// + verticalScrollBar()->sizeHint().width(),
+// + verticalScrollBar()->tqsizeHint().width(),
rowPos( rows()-1+(isInsertingEnabled()?1:0) ) + d->rowHeight
- + (horizontalScrollBar()->isVisible() ? 0 : horizontalScrollBar()->sizeHint().height())
+ + (horizontalScrollBar()->isVisible() ? 0 : horizontalScrollBar()->tqsizeHint().height())
+ d->internal_bottomMargin
-// horizontalScrollBar()->sizeHint().height()/2
-// - /*d->bottomMargin */ horizontalScrollBar()->sizeHint().height()*3/2
+// horizontalScrollBar()->tqsizeHint().height()/2
+// - /*d->bottomMargin */ horizontalScrollBar()->tqsizeHint().height()*3/2
// + ( (m_navPanel && m_navPanel->isVisible() && verticalScrollBar()->isVisible()
// && !horizontalScrollBar()->isVisible())
- // ? horizontalScrollBar()->sizeHint().height() : 0)
+ // ? horizontalScrollBar()->tqsizeHint().height() : 0)
// + TQMAX( (m_navPanel && m_navPanel->isVisible()) ? m_navPanel->height() : 0,
-// horizontalScrollBar()->isVisible() ? horizontalScrollBar()->sizeHint().height() : 0)
+// horizontalScrollBar()->isVisible() ? horizontalScrollBar()->tqsizeHint().height() : 0)
// + (m_navPanel->isVisible()
-// ? TQMAX( m_navPanel->height(), horizontalScrollBar()->sizeHint().height() ) :0 )
+// ? TQMAX( m_navPanel->height(), horizontalScrollBar()->tqsizeHint().height() ) :0 )
-// - (horizontalScrollBar()->isVisible() ? horizontalScrollBar()->sizeHint().height() :0 )
+// - (horizontalScrollBar()->isVisible() ? horizontalScrollBar()->tqsizeHint().height() :0 )
+ margin()
//-2*d->rowHeight
);
// kexidbg << rows()-1 <<" "<< (isInsertingEnabled()?1:0) <<" "<< (m_rowEditing?1:0) << " " << s << endl;
return s;
-// +horizontalScrollBar()->sizeHint().height() + margin() );
+// +horizontalScrollBar()->tqsizeHint().height() + margin() );
}
return TQSize(0,0);
}
@@ -2271,13 +2271,13 @@ void KexiTableView::setVerticalHeaderVisible(bool set)
int left_width;
if (set) {
m_verticalHeader->show();
- left_width = TQMIN(m_horizontalHeader->sizeHint().height(), d->rowHeight);
+ left_width = TQMIN(m_horizontalHeader->tqsizeHint().height(), d->rowHeight);
}
else {
m_verticalHeader->hide();
left_width = 0;
}
- setMargins( left_width, horizontalHeaderVisible() ? m_horizontalHeader->sizeHint().height() : 0, 0, 0);
+ setMargins( left_width, horizontalHeaderVisible() ? m_horizontalHeader->tqsizeHint().height() : 0, 0, 0);
}
bool KexiTableView::horizontalHeaderVisible() const
@@ -2291,7 +2291,7 @@ void KexiTableView::setHorizontalHeaderVisible(bool set)
d->horizontalHeaderVisible = set; //needed because isVisible() is not always accurate
if (set) {
m_horizontalHeader->show();
- top_height = m_horizontalHeader->sizeHint().height();
+ top_height = m_horizontalHeader->tqsizeHint().height();
}
else {
m_horizontalHeader->hide();
@@ -2478,10 +2478,10 @@ bool KexiTableView::eventFilter( TQObject *o, TQEvent *e )
}
/* else if (e->type()==TQEvent::FocusOut && o->inherits(TQWIDGET_OBJECT_NAME_STRING)) {
//hp==true if currently focused widget is a child of this table view
- const bool hp = KexiUtils::hasParent( static_cast<TQWidget*>(o), focusWidget());
+ const bool hp = KexiUtils::hasParent( static_cast<TQWidget*>(o), tqfocusWidget());
if (!hp && KexiUtils::hasParent( this, static_cast<TQWidget*>(o))) {
//accept row editing if focus is moved to foreign widget
- //(not a child, like eg. editor) from one of our table view's children
+ //(not a child, like eg. editor) from one of our table view's tqchildren
//or from table view itself
if (!acceptRowEdit()) {
static_cast<TQWidget*>(o)->setFocus();
@@ -2508,9 +2508,9 @@ void KexiTableView::paletteChange( const TQPalette &oldPalette )
Q_UNUSED(oldPalette);
//update:
if (m_verticalHeader)
- m_verticalHeader->setSelectionBackgroundColor( palette().active().highlight() );
+ m_verticalHeader->setSelectionBackgroundColor( tqpalette().active().highlight() );
if (m_horizontalHeader)
- m_horizontalHeader->setSelectionBackgroundColor( palette().active().highlight() );
+ m_horizontalHeader->setSelectionBackgroundColor( tqpalette().active().highlight() );
}
const KexiTableView::Appearance& KexiTableView::appearance() const
@@ -2531,8 +2531,8 @@ void KexiTableView::setAppearance(const Appearance& a)
m_verticalHeader->setCellHeight(d->rowHeight);
if (m_horizontalHeader) {
setMargins(
- TQMIN(m_horizontalHeader->sizeHint().height(), d->rowHeight),
- m_horizontalHeader->sizeHint().height(), 0, 0);
+ TQMIN(m_horizontalHeader->tqsizeHint().height(), d->rowHeight),
+ m_horizontalHeader->tqsizeHint().height(), 0, 0);
}
// }
if (a.rowHighlightingEnabled)
diff --git a/kexi/widget/tableview/kexitableview_p.cpp b/kexi/widget/tableview/kexitableview_p.cpp
index 983378cb..d5e1641a 100644
--- a/kexi/widget/tableview/kexitableview_p.cpp
+++ b/kexi/widget/tableview/kexitableview_p.cpp
@@ -48,7 +48,7 @@ KexiTableViewPrivate::KexiTableViewPrivate(KexiTableView* t)
//moved scrollBarTipTimerCnt = 0;
//moved scrollBarTip = 0;
ensureCellVisibleOnShow = TQPoint(-1,-1);
- internal_bottomMargin = tv->horizontalScrollBar()->sizeHint().height()/2;
+ internal_bottomMargin = tv->horizontalScrollBar()->tqsizeHint().height()/2;
highlightedRow = -1;
moveCursorOnMouseRelease = false;
horizontalHeaderVisible = true;
diff --git a/kexi/widget/tableview/kexitableviewdata.cpp b/kexi/widget/tableview/kexitableviewdata.cpp
index a4e45daf..5905706b 100644
--- a/kexi/widget/tableview/kexitableviewdata.cpp
+++ b/kexi/widget/tableview/kexitableviewdata.cpp
@@ -509,8 +509,8 @@ int KexiTableViewData::cmpStr(Item item1, Item item2)
const TQString &as = m_leftTmp.toString();
const TQString &bs = m_rightTmp.toString();
- const TQChar *a = as.unicode();
- const TQChar *b = bs.unicode();
+ const TQChar *a = as.tqunicode();
+ const TQChar *b = bs.tqunicode();
if ( a == b )
return 0;
@@ -524,16 +524,16 @@ int KexiTableViewData::cmpStr(Item item1, Item item2)
int l=TQMIN(as.length(),bs.length());
- au = a->unicode();
- bu = b->unicode();
+ au = a->tqunicode();
+ bu = b->tqunicode();
au = (au <= 0x17e ? charTable[au] : 0xffff);
bu = (bu <= 0x17e ? charTable[bu] : 0xffff);
while (l-- && au == bu)
{
a++,b++;
- au = a->unicode();
- bu = b->unicode();
+ au = a->tqunicode();
+ bu = b->tqunicode();
au = (au <= 0x17e ? charTable[au] : 0xffff);
bu = (bu <= 0x17e ? charTable[bu] : 0xffff);
}
@@ -635,7 +635,7 @@ bool KexiTableViewData::updateRowEditBufferRef(KexiTableItem *item,
}
//! @todo if there're multiple views for this data, we need multiple buffers!
-bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool repaint)
+bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool tqrepaint)
{
if (!m_pRowEditBuffer)
return true; //nothing to do
@@ -655,7 +655,7 @@ bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool repaint)
if (val->isNull() && !f->isAutoIncrement()) {
//NOT NULL violated
m_result.msg = i18n("\"%1\" column requires a value to be entered.")
- .arg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
+ .tqarg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
m_result.desc = i18n("The column's constraint is declared as NOT NULL.");
m_result.column = col;
return false;
@@ -666,7 +666,7 @@ bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool repaint)
if (!f->isAutoIncrement() && (val->isNull() || KexiDB::isEmptyValue( f, *val ))) {
//NOT EMPTY violated
m_result.msg = i18n("\"%1\" column requires a value to be entered.")
- .arg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
+ .tqarg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
m_result.desc = i18n("The column's constraint is declared as NOT EMPTY.");
m_result.column = col;
return false;
@@ -721,12 +721,12 @@ js: TODO: use KexiMainWindowImpl::showErrorMessage(const TQString &title, KexiDB
m_pRowEditBuffer->clear();
- if (repaint)
+ if (tqrepaint)
emit rowRepaintRequested(item);
return true;
}
-bool KexiTableViewData::saveRowChanges(KexiTableItem& item, bool repaint)
+bool KexiTableViewData::saveRowChanges(KexiTableItem& item, bool tqrepaint)
{
kdDebug() << "KexiTableViewData::saveRowChanges()..." << endl;
m_result.clear();
@@ -734,32 +734,32 @@ bool KexiTableViewData::saveRowChanges(KexiTableItem& item, bool repaint)
if (!m_result.success)
return false;
- if (saveRow(item, false /*update*/, repaint)) {
+ if (saveRow(item, false /*update*/, tqrepaint)) {
emit rowUpdated(&item);
return true;
}
return false;
}
-bool KexiTableViewData::saveNewRow(KexiTableItem& item, bool repaint)
+bool KexiTableViewData::saveNewRow(KexiTableItem& item, bool tqrepaint)
{
kdDebug() << "KexiTableViewData::saveNewRow()..." << endl;
m_result.clear();
- emit aboutToInsertRow(&item, &m_result, repaint);
+ emit aboutToInsertRow(&item, &m_result, tqrepaint);
if (!m_result.success)
return false;
- if (saveRow(item, true /*insert*/, repaint)) {
- emit rowInserted(&item, repaint);
+ if (saveRow(item, true /*insert*/, tqrepaint)) {
+ emit rowInserted(&item, tqrepaint);
return true;
}
return false;
}
-bool KexiTableViewData::deleteRow(KexiTableItem& item, bool repaint)
+bool KexiTableViewData::deleteRow(KexiTableItem& item, bool tqrepaint)
{
m_result.clear();
- emit aboutToDeleteRow(item, &m_result, repaint);
+ emit aboutToDeleteRow(item, &m_result, tqrepaint);
if (!m_result.success)
return false;
@@ -784,9 +784,9 @@ bool KexiTableViewData::deleteRow(KexiTableItem& item, bool repaint)
return true;
}
-void KexiTableViewData::deleteRows( const TQValueList<int> &rowsToDelete, bool repaint )
+void KexiTableViewData::deleteRows( const TQValueList<int> &rowsToDelete, bool tqrepaint )
{
- Q_UNUSED( repaint );
+ Q_UNUSED( tqrepaint );
if (rowsToDelete.isEmpty())
return;
@@ -804,11 +804,11 @@ void KexiTableViewData::deleteRows( const TQValueList<int> &rowsToDelete, bool r
emit rowsDeleted( rowsToDelete );
}
-void KexiTableViewData::insertRow(KexiTableItem& item, uint index, bool repaint)
+void KexiTableViewData::insertRow(KexiTableItem& item, uint index, bool tqrepaint)
{
if (!insert( index = TQMIN(index, count()), &item ))
return;
- emit rowInserted(&item, index, repaint);
+ emit rowInserted(&item, index, tqrepaint);
}
void KexiTableViewData::clearInternal()
@@ -822,12 +822,12 @@ void KexiTableViewData::clearInternal()
removeLast();
#ifndef KEXI_NO_PROCESS_EVENTS
if (i % 1000 == 0)
- tqApp->processEvents( 1 );
+ tqApp->tqprocessEvents( 1 );
#endif
}
}
-bool KexiTableViewData::deleteAllRows(bool repaint)
+bool KexiTableViewData::deleteAllRows(bool tqrepaint)
{
clearInternal();
@@ -837,7 +837,7 @@ bool KexiTableViewData::deleteAllRows(bool repaint)
res = m_cursor->deleteAllRows();
}
- if (repaint)
+ if (tqrepaint)
emit reloadRequested();
return res;
}
@@ -873,7 +873,7 @@ void KexiTableViewData::preloadAllRows()
m_cursor->moveNext();
#ifndef KEXI_NO_PROCESS_EVENTS
if ((i % 1000) == 0)
- tqApp->processEvents( 1 );
+ tqApp->tqprocessEvents( 1 );
#endif
}
}
diff --git a/kexi/widget/tableview/kexitableviewdata.h b/kexi/widget/tableview/kexitableviewdata.h
index eb3d20df..7263f3fe 100644
--- a/kexi/widget/tableview/kexitableviewdata.h
+++ b/kexi/widget/tableview/kexitableviewdata.h
@@ -359,27 +359,27 @@ public:
/*! \return last operation's result information (always not null). */
inline KexiDB::ResultInfo* result() { return &m_result; }
- bool saveRowChanges(KexiTableItem& item, bool repaint = false);
+ bool saveRowChanges(KexiTableItem& item, bool tqrepaint = false);
- bool saveNewRow(KexiTableItem& item, bool repaint = false);
+ bool saveNewRow(KexiTableItem& item, bool tqrepaint = false);
- bool deleteRow(KexiTableItem& item, bool repaint = false);
+ bool deleteRow(KexiTableItem& item, bool tqrepaint = false);
/*! Deletes rows (by number) passed with \a rowsToDelete.
Currently, this method is only for non data-aware tables. */
- void deleteRows( const TQValueList<int> &rowsToDelete, bool repaint = false );
+ void deleteRows( const TQValueList<int> &rowsToDelete, bool tqrepaint = false );
/*! Deletes all rows. Works either for db-aware and non db-aware tables.
Column's definition is not changed.
For db-aware version, all rows are removed from a database.
Row-edit buffer is cleared.
- If \a repaint is true, reloadRequested() signal
+ If \a tqrepaint is true, reloadRequested() signal
is emitted after deleting (if at least one row was deleted),
- so presenters can repaint their contents.
+ so presenters can tqrepaint their contents.
\return true on success. */
- virtual bool deleteAllRows(bool repaint = false);
+ virtual bool deleteAllRows(bool tqrepaint = false);
/*! @internal method, used mostly by specialized classes like KexiTableView.
Clears internal row structures. Row-edit buffer is cleared.
@@ -390,7 +390,7 @@ public:
/*! Inserts new \a item at index \a index.
\a item will be owned by this data object.
Note: Reasonable only for not not-db-aware version. */
- void insertRow(KexiTableItem& item, uint index, bool repaint = false);
+ void insertRow(KexiTableItem& item, uint index, bool tqrepaint = false);
/*TODO: add this as well?
void insertRow(KexiTableItem& item, KexiTableItem& aboveItem); */
@@ -445,7 +445,7 @@ signals:
/*! Emited before inserting of a new, current row.
Connect this signal to your slot and set \a result->success to false
to disallow this inserting. You can also change columns in \a item row. */
- void aboutToInsertRow(KexiTableItem *item, KexiDB::ResultInfo* result, bool repaint);
+ void aboutToInsertRow(KexiTableItem *item, KexiDB::ResultInfo* result, bool tqrepaint);
/*! Emited before changing of an edited, current row.
Connect this signal to your slot and set \a result->success to false
@@ -455,15 +455,15 @@ signals:
void rowUpdated(KexiTableItem*); //!< Current row has been updated
- void rowInserted(KexiTableItem*, bool repaint); //!< A row has been inserted
+ void rowInserted(KexiTableItem*, bool tqrepaint); //!< A row has been inserted
//! A row has been inserted at \a index position (not db-aware data only)
- void rowInserted(KexiTableItem*, uint index, bool repaint);
+ void rowInserted(KexiTableItem*, uint index, bool tqrepaint);
/*! Emited before deleting of a current row.
Connect this signal to your slot and set \a result->success to false
to disallow this deleting. */
- void aboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool repaint);
+ void aboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool tqrepaint);
//! Current row has been deleted
void rowDeleted();
@@ -497,7 +497,7 @@ protected:
int cmpBLOB(Item item1, Item item2);
//! internal: for saveRowChanges() and saveNewRow()
- bool saveRow(KexiTableItem& item, bool insert, bool repaint);
+ bool saveRow(KexiTableItem& item, bool insert, bool tqrepaint);
//! (logical) sorted column number, set by setSorting()
//! can differ from m_realSortedColumn if there's lookup column used
diff --git a/kexi/widget/tableview/kexitableviewheader.cpp b/kexi/widget/tableview/kexitableviewheader.cpp
index ef4c83da..4a00be38 100644
--- a/kexi/widget/tableview/kexitableviewheader.cpp
+++ b/kexi/widget/tableview/kexitableviewheader.cpp
@@ -34,7 +34,7 @@ class KexiTableViewHeaderStyle : public KexiUtils::StyleProxy
KexiTableViewHeaderStyle(TQStyle *parentStyle, TQWidget *widget)
: KexiUtils::StyleProxy(parentStyle)
{
- setBackgroundColor( widget->palette().active().background() );
+ setBackgroundColor( widget->tqpalette().active().background() );
}
~KexiTableViewHeaderStyle() {}
@@ -61,7 +61,7 @@ class KexiTableViewHeaderStyle : public KexiUtils::StyleProxy
KexiTableViewHeader::KexiTableViewHeader(TQWidget * parent, const char * name)
: TQHeader(parent, name)
, m_lastToolTipSection(-1)
- , m_selectionBackgroundColor(tqApp->palette().active().highlight())
+ , m_selectionBackgroundColor(tqApp->tqpalette().active().highlight())
, m_selectedSection(-1)
, m_styleChangeEnabled(true)
{
@@ -126,7 +126,7 @@ bool KexiTableViewHeader::eventFilter(TQObject * watched, TQEvent * e)
TQString tip = m_toolTips[ section ];
if (tip.isEmpty()) { //try label
TQFontMetrics fm(font());
- int minWidth = fm.width( label( section ) ) + tqstyle().pixelMetric( TQStyle::PM_HeaderMargin );
+ int minWidth = fm.width( label( section ) ) + tqstyle().tqpixelMetric( TQStyle::PM_HeaderMargin );
TQIconSet *iset = iconSet( section );
if (iset)
minWidth += (2+iset->pixmap( TQIconSet::Small, TQIconSet::Normal ).width()); //taken from TQHeader::sectionSizeHint()
@@ -188,14 +188,14 @@ void KexiTableViewHeader::paintSection( TQPainter * p, int index, const TQRect &
if (paintSelection) {
static_cast<KexiTableViewHeaderStyle&>(tqstyle()).setBackgroundColor(
KexiUtils::blendedColors(
- palette().active().background(), m_selectionBackgroundColor, 2, 1) );
+ tqpalette().active().background(), m_selectionBackgroundColor, 2, 1) );
}
TQHeader::paintSection( p, index, fr );
if (paintSelection) { //revert the color for subsequent paints
static_cast<KexiTableViewHeaderStyle&>(tqstyle()).setBackgroundColor(
- palette().active().background());
+ tqpalette().active().background());
}
}
diff --git a/kexi/widget/tableview/kexitimetableedit.cpp b/kexi/widget/tableview/kexitimetableedit.cpp
index 6035aed5..8110716b 100644
--- a/kexi/widget/tableview/kexitimetableedit.cpp
+++ b/kexi/widget/tableview/kexitimetableedit.cpp
@@ -23,16 +23,16 @@
#include <tqpainter.h>
#include <tqvariant.h>
#include <tqrect.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqcolor.h>
#include <tqfontmetrics.h>
#include <tqdatetime.h>
#include <tqcursor.h>
#include <tqpoint.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtoolbutton.h>
#include <tqdatetimeedit.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <kdebug.h>
#include <klocale.h>
diff --git a/kexi/widget/tableview/kexidataawareobjectiface.cpp b/kexi/widget/tableview/kexidataawareobjectiface.cpp
index ce0b7695..79613d9d 100644
--- a/kexi/widget/tableview/kexidataawareobjectiface.cpp
+++ b/kexi/widget/tableview/kexidataawareobjectiface.cpp
@@ -84,7 +84,7 @@ KexiDataAwareObjectInterface::KexiDataAwareObjectInterface()
m_scrollBarTip->setPalette(TQToolTip::palette());
m_scrollBarTip->setMargin(2);
m_scrollBarTip->setIndent(0);
- m_scrollBarTip->setAlignment(TQt::AlignCenter);
+ m_scrollBarTip->tqsetAlignment(TQt::AlignCenter);
m_scrollBarTip->setFrameStyle( TQFrame::Plain | TQFrame::Box );
m_scrollBarTip->setLineWidth(1);
@@ -539,8 +539,8 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
if ( forceSet || m_curRow != newrow || m_curCol != newcol )
{
- kexidbg << "setCursorPosition(): " <<TQString("old:%1,%2 new:%3,%4").arg(m_curCol)
- .arg(m_curRow).arg(newcol).arg(newrow) << endl;
+ kexidbg << "setCursorPosition(): " <<TQString("old:%1,%2 new:%3,%4").tqarg(m_curCol)
+ .tqarg(m_curRow).tqarg(newcol).tqarg(newrow) << endl;
// cursor moved: get rid of editor
if (m_editor) {
@@ -645,7 +645,7 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
}
else {
kdDebug(44021) << TQString("NOW item at %1 (%2) is current")
- .arg(m_curRow).arg((ulong)itemAt(m_curRow)) << endl;
+ .tqarg(m_curRow).tqarg((ulong)itemAt(m_curRow)) << endl;
//NOT EFFECTIVE!!!!!!!!!!!
//set item iterator
if (!newRowInserted && isInsertingEnabled() && m_currentItem == m_insertItem && m_curRow == (rows()-1)) {
@@ -838,7 +838,7 @@ bool KexiDataAwareObjectInterface::cancelRowEdit()
// viewport()->width(), d->rowHeight*3 + (m_navPanel ? m_navPanel->height() : 0)*3 );
// updateContents(); //js: above did not work well so we do that dirty
updateWidgetContents();
//TODO: still doesn't repaint properly!!
// TQSize s(tableSize());
// resizeContents(s.width(), s.height());
updateWidgetContentsSize();
@@ -940,7 +940,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
if (!m_errorMessagePopup) {
// m_errorMessagePopup->close();
m_errorMessagePopup = new KexiArrowTip(
- i18n("Error: %1").arg(m_editor->columnInfo()->field->typeName())+"?",
+ i18n("Error: %1").tqarg(m_editor->columnInfo()->field->typeName())+"?",
dynamic_cast<TQWidget*>(this));
m_errorMessagePopup->move(
par->mapToGlobal(edit->pos()) + TQPoint(6, edit->height() + 0) );
@@ -954,8 +954,8 @@ bool KexiDataAwareObjectInterface::acceptEditor()
if (m_editor->field()->isNotNull() && !autoIncColumnCanBeOmitted) {
kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NULL NOT ALLOWED!" << endl;
res = Validator::Error;
-// msg = Validator::msgColumnNotEmpty().arg(m_editor->columnInfo()->field->captionOrName())
- msg = Validator::msgColumnNotEmpty().arg(m_editor->field()->captionOrName())
+// msg = Validator::msgColumnNotEmpty().tqarg(m_editor->columnInfo()->field->captionOrName())
+ msg = Validator::msgColumnNotEmpty().tqarg(m_editor->field()->captionOrName())
+ "\n\n" + Kexi::msgYouCanImproveData();
desc = i18n("The column's constraint is declared as NOT NULL.");
editCurrentCellAgain = true;
@@ -976,8 +976,8 @@ bool KexiDataAwareObjectInterface::acceptEditor()
if (m_editor->field()->isNotEmpty() && !autoIncColumnCanBeOmitted) {
kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): EMPTY NOT ALLOWED!" << endl;
res = Validator::Error;
-// msg = Validator::msgColumnNotEmpty().arg(m_editor->columnInfo()->field->captionOrName())
- msg = Validator::msgColumnNotEmpty().arg(m_editor->field()->captionOrName())
+// msg = Validator::msgColumnNotEmpty().tqarg(m_editor->columnInfo()->field->captionOrName())
+ msg = Validator::msgColumnNotEmpty().tqarg(m_editor->field()->captionOrName())
+ "\n\n" + Kexi::msgYouCanImproveData();
desc = i18n("The column's constraint is declared as NOT EMPTY.");
editCurrentCellAgain = true;
@@ -994,8 +994,8 @@ bool KexiDataAwareObjectInterface::acceptEditor()
if (m_editor->field()->isNotNull() && !autoIncColumnCanBeOmitted) {
kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NEITHER NULL NOR EMPTY VALUE CAN BE SET!" << endl;
res = Validator::Error;
-// msg = Validator::msgColumnNotEmpty().arg(m_editor->columnInfo()->field->captionOrName())
- msg = Validator::msgColumnNotEmpty().arg(m_editor->field()->captionOrName())
+// msg = Validator::msgColumnNotEmpty().tqarg(m_editor->columnInfo()->field->captionOrName())
+ msg = Validator::msgColumnNotEmpty().tqarg(m_editor->field()->captionOrName())
+ "\n\n" + Kexi::msgYouCanImproveData();
desc = i18n("The column's constraint is declared as NOT EMPTY and NOT NULL.");
editCurrentCellAgain = true;
@@ -1251,7 +1251,7 @@ void KexiDataAwareObjectInterface::insertItem(KexiTableItem *newItem, int row)
m_curRow++;
}
- m_data->insertRow(*newItem, row, true /*repaint*/);
+ m_data->insertRow(*newItem, row, true /*tqrepaint*/);
if (changeCurrentRow) {
//update iter...
@@ -1281,15 +1281,15 @@ void KexiDataAwareObjectInterface::insertItem(KexiTableItem *newItem, int row)
*/
}
-void KexiDataAwareObjectInterface::slotRowInserted(KexiTableItem *item, bool repaint)
+void KexiDataAwareObjectInterface::slotRowInserted(KexiTableItem *item, bool tqrepaint)
{
int row = m_data->findRef(item);
- slotRowInserted( item, row, repaint );
+ slotRowInserted( item, row, tqrepaint );
}
-void KexiDataAwareObjectInterface::slotRowInserted(KexiTableItem * /*item*/, uint row, bool repaint)
+void KexiDataAwareObjectInterface::slotRowInserted(KexiTableItem * /*item*/, uint row, bool tqrepaint)
{
- if (repaint && (int)row<rows()) {
+ if (tqrepaint && (int)row<rows()) {
updateWidgetContentsSize();
/* updateAllVisibleRowsBelow() used instead
@@ -1317,7 +1317,7 @@ void KexiDataAwareObjectInterface::slotRowInserted(KexiTableItem * /*item*/, uin
}
}
-tristate KexiDataAwareObjectInterface::deleteAllRows(bool ask, bool repaint)
+tristate KexiDataAwareObjectInterface::deleteAllRows(bool ask, bool tqrepaint)
{
if (!hasData())
return true;
@@ -1331,7 +1331,7 @@ tristate KexiDataAwareObjectInterface::deleteAllRows(bool ask, bool repaint)
tableName.append("\"");
}
if (KMessageBox::Cancel == KMessageBox::warningContinueCancel(dynamic_cast<TQWidget*>(this),
- i18n("Do you want to clear the contents of table %1?").arg(tableName),
+ i18n("Do you want to clear the contents of table %1?").tqarg(tableName),
0, KGuiItem(i18n("&Clear Contents")) ))
return cancelled;
}
@@ -1339,10 +1339,10 @@ tristate KexiDataAwareObjectInterface::deleteAllRows(bool ask, bool repaint)
cancelRowEdit();
// acceptRowEdit();
// m_verticalHeader->clear();
- const bool repaintLater = repaint && m_spreadSheetMode;
+ const bool repaintLater = tqrepaint && m_spreadSheetMode;
const int oldRows = rows();
- bool res = m_data->deleteAllRows(repaint && !repaintLater);
+ bool res = m_data->deleteAllRows(tqrepaint && !repaintLater);
if (res) {
if (m_spreadSheetMode) {
@@ -1359,21 +1359,21 @@ tristate KexiDataAwareObjectInterface::deleteAllRows(bool ask, bool repaint)
// m_verticalHeader->setCurrentRow(-1);
// d->pUpdateTimer->start(1,true);
-// if (repaint)
-// viewport()->repaint();
+// if (tqrepaint)
+// viewport()->tqrepaint();
return res;
}
-void KexiDataAwareObjectInterface::clearColumns(bool repaint)
+void KexiDataAwareObjectInterface::clearColumns(bool tqrepaint)
{
cancelRowEdit();
m_data->clearInternal();
- clearColumnsInternal(repaint);
+ clearColumnsInternal(tqrepaint);
updateIndicesForVisibleValues();
- if (repaint)
-// viewport()->repaint();
+ if (tqrepaint)
+// viewport()->tqrepaint();
//OK?
updateWidgetContents();
@@ -1393,7 +1393,7 @@ void KexiDataAwareObjectInterface::clearColumns(bool repaint)
m_verticalHeader->setCurrentRow(-1);
- viewport()->repaint();
+ viewport()->tqrepaint();
// d->pColumnTypes.resize(0);
// d->pColumnModes.resize(0);
@@ -1490,9 +1490,9 @@ void KexiDataAwareObjectInterface::setEmptyRowInsertingEnabled(bool set)
}
void KexiDataAwareObjectInterface::slotAboutToDeleteRow(KexiTableItem& item,
- KexiDB::ResultInfo* /*result*/, bool repaint)
+ KexiDB::ResultInfo* /*result*/, bool tqrepaint)
{
- if (repaint) {
+ if (tqrepaint) {
m_rowWillBeDeleted = m_data->findRef(&item);
}
}
@@ -1534,7 +1534,7 @@ bool KexiDataAwareObjectInterface::deleteItem(KexiTableItem *item)/*, bool moveC
const bool lastRowDeleted = m_spreadSheetMode && m_data->last() == item; //we need to know this so we
//can return to the last row
//after reinserting it
- if (!m_data->deleteRow(*item, true /*repaint*/)) {
+ if (!m_data->deleteRow(*item, true /*tqrepaint*/)) {
/*const int button =*/
showErrorMessageForResult( m_data->result() );
// if (KMessageBox::No == button) {
@@ -1950,7 +1950,7 @@ static inline bool findInString(const TQString& stringValue, int stringLength, c
if (firstCharacter != -1 && firstCharacter != 0) { //we're not at 0-th char
firstCharacter = -1;
}
- else if (where.startsWith(stringValue, caseSensitive)) {
+ else if (where.tqstartsWith(stringValue, caseSensitive)) {
if (wholeWordsOnly) {
// If where.length() < stringValue.length(), true will be returned too - fine.
return !where.at( stringValue.length() ).isLetterOrNumber();
@@ -838,7 +838,7 @@ bool KexiDataAwareObjectInterface::cancelRowEdit()
// updateContents(); //js: above did not work well so we do that dirty
updateWidgetContents();
-//TODO: still doesn't repaint properly!!
+//TODO: still doesn't tqrepaint properly!!
// TQSize s(tableSize());
// resizeContents(s.width(), s.height());
diff --git a/kexi/widget/tableview/kexidataawareobjectiface.h b/kexi/widget/tableview/kexidataawareobjectiface.h
index 0fed82b6..389c1c74 100644
--- a/kexi/widget/tableview/kexidataawareobjectiface.h
+++ b/kexi/widget/tableview/kexidataawareobjectiface.h
@@ -267,14 +267,14 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
Does not clear columns information.
Does not destroy KexiTableViewData object (if present) but only clears its contents.
Displays confirmation dialog if \a ask is true (the default is false).
- Repaints widget if \a repaint is true (the default).
+ Repaints widget if \a tqrepaint is true (the default).
For empty tables, true is returned immediately.
If isDeleteEnabled() is false, false is returned.
For spreadsheet mode all current rows are just replaced by empty rows.
\return true on success, false on failure, and cancelled if user cancelled deletion
(only possible if \a ask is true).
*/
- tristate deleteAllRows(bool ask = false, bool repaint = true);
+ tristate deleteAllRows(bool ask = false, bool tqrepaint = true);
/*! \return maximum number of rows that can be displayed per one "page"
for current view's size. */
@@ -537,12 +537,12 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
virtual void initDataContents();
/*! Clears columns information and thus all internal table data
- and its visible representation. Repaints widget if \a repaint is true. */
- virtual void clearColumns(bool repaint = true);
+ and its visible representation. Repaints widget if \a tqrepaint is true. */
+ virtual void clearColumns(bool tqrepaint = true);
/*! Called by clearColumns() to clear internals of the object.
For example, KexiTableView removes contents of it's horizontal header. */
- virtual void clearColumnsInternal(bool repaint) = 0;
+ virtual void clearColumnsInternal(bool tqrepaint) = 0;
/*! @internal for implementation
This should append another section within horizontal header or any sort of caption
@@ -654,16 +654,16 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
//! Handles KexiTableViewData::aboutToDeleteRow() signal. Prepares info for slotRowDeleted().
virtual void slotAboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result,
- bool repaint);
+ bool tqrepaint);
- //! Handles KexiTableViewData::rowDeleted() signal to repaint when needed.
+ //! Handles KexiTableViewData::rowDeleted() signal to tqrepaint when needed.
virtual void slotRowDeleted();
- //! Handles KexiTableViewData::rowInserted() signal to repaint when needed.
- virtual void slotRowInserted(KexiTableItem *item, bool repaint);
+ //! Handles KexiTableViewData::rowInserted() signal to tqrepaint when needed.
+ virtual void slotRowInserted(KexiTableItem *item, bool tqrepaint);
//! Like above, not db-aware version
- virtual void slotRowInserted(KexiTableItem *item, uint row, bool repaint);
+ virtual void slotRowInserted(KexiTableItem *item, uint row, bool tqrepaint);
virtual void slotRowsDeleted( const TQValueList<int> & ) {}
@@ -675,7 +675,7 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
virtual void selectCellInternal() {}
/*! Used in KexiDataAwareObjectInterface::slotRowDeleted()
- to repaint tow \a row and all visible below.
+ to tqrepaint tow \a row and all visible below.
Implemented if there is more than one row displayed, i.e. currently for KexiTableView. */
virtual void updateAllVisibleRowsBelow(int row) { Q_UNUSED( row ); }
diff --git a/kexi/widget/tableview/kexitableview.h b/kexi/widget/tableview/kexitableview.h
index b602168a..9cfcf47e 100644
--- a/kexi/widget/tableview/kexitableview.h
+++ b/kexi/widget/tableview/kexitableview.h
@@ -223,8 +223,8 @@ public:
// reimplemented for internal reasons
virtual TQSizePolicy sizePolicy() const;
- virtual TQSize sizeHint() const;
- virtual TQSize minimumSizeHint() const;
+ virtual TQSize tqsizeHint() const;
+ virtual TQSize tqminimumSizeHint() const;
/*! Reimplemented to update cached fonts and row sizes for the painter. */
void setFont(const TQFont &f);
@@ -263,7 +263,7 @@ public slots:
virtual void setData( KexiTableViewData *data, bool owner = true )
{ KexiDataAwareObjectInterface::setData( data, owner ); }
- virtual void clearColumnsInternal(bool repaint);
+ virtual void clearColumnsInternal(bool tqrepaint);
/*! Adjusts \a colNum column's width to its (current) contents.
If \a colNum == -1, all columns' width is adjusted. */
@@ -432,19 +432,19 @@ protected slots:
virtual void slotRowRepaintRequested(KexiTableItem& item);
//! Handles KexiTableViewData::aboutToDeleteRow() signal. Prepares info for slotRowDeleted().
- virtual void slotAboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool repaint)
- { KexiDataAwareObjectInterface::slotAboutToDeleteRow(item, result, repaint); }
+ virtual void slotAboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool tqrepaint)
+ { KexiDataAwareObjectInterface::slotAboutToDeleteRow(item, result, tqrepaint); }
- //! Handles KexiTableViewData::rowDeleted() signal to repaint when needed.
+ //! Handles KexiTableViewData::rowDeleted() signal to tqrepaint when needed.
virtual void slotRowDeleted() { KexiDataAwareObjectInterface::slotRowDeleted(); }
- //! Handles KexiTableViewData::rowInserted() signal to repaint when needed.
- virtual void slotRowInserted(KexiTableItem *item, bool repaint)
- { KexiDataAwareObjectInterface::slotRowInserted(item, repaint); }
+ //! Handles KexiTableViewData::rowInserted() signal to tqrepaint when needed.
+ virtual void slotRowInserted(KexiTableItem *item, bool tqrepaint)
+ { KexiDataAwareObjectInterface::slotRowInserted(item, tqrepaint); }
//! Like above, not db-aware version
- virtual void slotRowInserted(KexiTableItem *item, uint row, bool repaint)
- { KexiDataAwareObjectInterface::slotRowInserted(item, row, repaint); }
+ virtual void slotRowInserted(KexiTableItem *item, uint row, bool tqrepaint)
+ { KexiDataAwareObjectInterface::slotRowInserted(item, row, tqrepaint); }
/*! Handles verticalScrollBar()'s valueChanged(int) signal.
Called when vscrollbar's value has been changed. */
@@ -504,7 +504,7 @@ protected:
*value is set to the default value. */
bool isDefaultValueDisplayed(KexiTableItem *item, int col, TQVariant* value = 0);
- //! painting and layout
+ //! painting and tqlayout
void drawContents(TQPainter *p, int cx, int cy, int cw, int ch);
void createBuffer(int width, int height);
void paintCell(TQPainter* p, KexiTableItem *item, int col, int row, const TQRect &cr, bool print=false);
@@ -588,7 +588,7 @@ protected:
virtual void removeEditor();
//! Internal: updated sched fonts for painting.
- void updateFonts(bool repaint = false);
+ void updateFonts(bool tqrepaint = false);
/*! @internal Changes bottom margin settings, in pixels.
At this time, it's used by KexiComboBoxPopup to decrease margin for popup's table. */
@@ -614,7 +614,7 @@ protected:
virtual void paste();
/*! Used in KexiDataAwareObjectInterface::slotRowDeleted()
- to repaint tow \a row and all visible below. */
+ to tqrepaint tow \a row and all visible below. */
virtual void updateAllVisibleRowsBelow(int row);
void updateAfterCancelRowEdit();
@@ -626,7 +626,7 @@ protected:
bool getVisibleLookupValue(TQVariant& cellValue, KexiTableEdit *edit,
KexiTableItem *item, KexiTableViewColumn *tvcol) const;
// //! Called to repaint contents after a row is deleted.
// void repaintAfterDelete();
KexiTableViewPrivate *d;
@@ -626,7 +626,7 @@ protected:
bool getVisibleLookupValue(TQVariant& cellValue, KexiTableEdit *edit,
KexiTableItem *item, KexiTableViewColumn *tvcol) const;
-// //! Called to repaint contents after a row is deleted.
+// //! Called to tqrepaint contents after a row is deleted.
// void repaintAfterDelete();
KexiTableViewPrivate *d;